# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_store.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_store.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19steammessages_store.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"\xa1\x02\n\x1c\x43Store_RegisterCDKey_Request\x12S\n\x0f\x61\x63tivation_code\x18\x01 \x01(\tB:\x82\xb5\x18\x36Key string to register on the logged in user\'s account\x12H\n\x11purchase_platform\x18\x02 \x01(\x05\x42-\x82\xb5\x18)EPurchasePlatform for platform of request\x12\x62\n\x16is_request_from_client\x18\x03 \x01(\x08\x42\x42\x82\xb5\x18>True if the request was initiated from inside the Steam client\"\x9b\x04\n\x1a\x43Store_PurchaseReceiptInfo\x12\x15\n\rtransactionid\x18\x01 \x01(\x04\x12\x11\n\tpackageid\x18\x02 \x01(\r\x12\x17\n\x0fpurchase_status\x18\x03 \x01(\r\x12\x15\n\rresult_detail\x18\x04 \x01(\r\x12\x18\n\x10transaction_time\x18\x05 \x01(\r\x12\x16\n\x0epayment_method\x18\x06 \x01(\r\x12\x12\n\nbase_price\x18\x07 \x01(\x04\x12\x16\n\x0etotal_discount\x18\x08 \x01(\x04\x12\x0b\n\x03tax\x18\t \x01(\x04\x12\x10\n\x08shipping\x18\n \x01(\x04\x12\x15\n\rcurrency_code\x18\x0b \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x0c \x01(\t\x12\x16\n\x0e\x65rror_headline\x18\r \x01(\t\x12\x14\n\x0c\x65rror_string\x18\x0e \x01(\t\x12\x17\n\x0f\x65rror_link_text\x18\x0f \x01(\t\x12\x16\n\x0e\x65rror_link_url\x18\x10 \x01(\t\x12\x13\n\x0b\x65rror_appid\x18\x11 \x01(\r\x12\x38\n\nline_items\x18\x12 \x03(\x0b\x32$.CStore_PurchaseReceiptInfo.LineItem\x1aK\n\x08LineItem\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x1d\n\x15line_item_description\x18\x03 \x01(\t\"\xc7\x01\n\x1d\x43Store_RegisterCDKey_Response\x12O\n\x17purchase_result_details\x18\x01 \x01(\x05\x42.\x82\xb5\x18*EPurchaseResultDetails from key activation\x12U\n\x15purchase_receipt_info\x18\x02 \x01(\x0b\x32\x1b.CStore_PurchaseReceiptInfoB\x19\x82\xb5\x18\x15Purchase receipt info\"5\n!CStore_GetMostPopularTags_Request\x12\x10\n\x08language\x18\x01 \x01(\t\"\x7f\n\"CStore_GetMostPopularTags_Response\x12\x35\n\x04tags\x18\x01 \x03(\x0b\x32\'.CStore_GetMostPopularTags_Response.Tag\x1a\"\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"J\n&CStore_GetLocalizedNameForTags_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0e\n\x06tagids\x18\x02 \x03(\r\"\x99\x02\n\'CStore_GetLocalizedNameForTags_Response\x12:\n\x04tags\x18\x01 \x03(\x0b\x32,.CStore_GetLocalizedNameForTags_Response.Tag\x1a\xb1\x01\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x14\n\x0c\x65nglish_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12w\n\x0fnormalized_name\x18\x04 \x01(\tB^\x82\xb5\x18Zenglish_name, lowercase, with homoglyphs replaced and spaces and some punctuation removed.\"\xe2\x03\n\x1c\x43StoreDiscoveryQueueSettings\x12\x0e\n\x06os_win\x18\x04 \x01(\x08\x12\x0e\n\x06os_mac\x18\x05 \x01(\x08\x12\x10\n\x08os_linux\x18\x06 \x01(\x08\x12\x1f\n\x17\x66ull_controller_support\x18\x07 \x01(\x08\x12\x1f\n\x17native_steam_controller\x18\x08 \x01(\x08\x12\x1b\n\x13include_coming_soon\x18\t \x01(\x08\x12\x44\n\x0f\x65xcluded_tagids\x18\n \x03(\rB+\x82\xb5\x18\'Don\'t return any games with these tags.\x12\x1c\n\x14\x65xclude_early_access\x18\x0b \x01(\x08\x12\x16\n\x0e\x65xclude_videos\x18\x0c \x01(\x08\x12\x18\n\x10\x65xclude_software\x18\r \x01(\x08\x12\x13\n\x0b\x65xclude_dlc\x18\x0e \x01(\x08\x12\x1b\n\x13\x65xclude_soundtracks\x18\x0f \x01(\x08\x12i\n\x0f\x66\x65\x61tured_tagids\x18\x10 \x03(\rBP\x82\xb5\x18LMust be marked with one of these featured tagids (for sale pages and events)\"\x85\x03\n CStore_GetDiscoveryQueue_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x15\n\rrebuild_queue\x18\x03 \x01(\x08\x12\x18\n\x10settings_changed\x18\x04 \x01(\x08\x12/\n\x08settings\x18\x05 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\x12\x1e\n\x16rebuild_queue_if_stale\x18\x06 \x01(\x08\x12\x1f\n\x17ignore_user_preferences\x18\x08 \x01(\x08\x12\x1f\n\x17no_experimental_results\x18\t \x01(\x08\x12\x1b\n\x13\x65xperimental_cohort\x18\n \x01(\r\x12\x1c\n\x14\x64\x65\x62ug_get_solr_query\x18\x0b \x01(\x08\"\xd5\x01\n!CStore_GetDiscoveryQueue_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12/\n\x08settings\x18\x03 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\x12\x0f\n\x07skipped\x18\x04 \x01(\x05\x12\x11\n\texhausted\x18\x05 \x01(\x08\x12\x1b\n\x13\x65xperimental_cohort\x18\x06 \x01(\r\x12\x18\n\x10\x64\x65\x62ug_solr_query\x18\x07 \x01(\t\"x\n(CStore_GetDiscoveryQueueSettings_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\"r\n)CStore_GetDiscoveryQueueSettings_Response\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12/\n\x08settings\x18\x02 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\"\x84\x01\n%CStore_SkipDiscoveryQueueItem_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"(\n&CStore_SkipDiscoveryQueueItem_Response\"a\n\'CStore_GetUserGameInterestState_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0bstore_appid\x18\x02 \x01(\r\x12\x12\n\nbeta_appid\x18\x03 \x01(\r\"\x9d\x08\n(CStore_GetUserGameInterestState_Response\x12\r\n\x05owned\x18\x01 \x01(\x08\x12\x10\n\x08wishlist\x18\x02 \x01(\x08\x12\x0f\n\x07ignored\x18\x03 \x01(\x08\x12\x11\n\tfollowing\x18\x04 \x01(\x08\x12,\n\tin_queues\x18\x05 \x03(\x0e\x32\x19.EStoreDiscoveryQueueType\x12t\n\x10queues_with_skip\x18\x06 \x03(\x0e\x32\x19.EStoreDiscoveryQueueTypeB?\x82\xb5\x18;Discovery queue types where the user has skipped this game.\x12t\n\x15queue_items_remaining\x18\x07 \x03(\x05\x42U\x82\xb5\x18Q# of items remaining in the discovery queue - matches the same order as in_queues\x12\x65\n\x16queue_items_next_appid\x18\x08 \x03(\rBE\x82\xb5\x18\x41the next appid in the queue - matches the same order as in_queues\x12^\n\x11temporarily_owned\x18\t \x01(\x08\x42\x43\x82\xb5\x18?The user owns the game temporarily, eg a rental or free weekend\x12\x41\n\x06queues\x18\n \x03(\x0b\x32\x31.CStore_GetUserGameInterestState_Response.InQueue\x12X\n\x0eignored_reason\x18\x0b \x01(\x05\x42@\x82\xb5\x18<The ERecommendationIgnoreReason why the user ignored the app\x12\x7f\n\x0b\x62\x65ta_status\x18\x0c \x01(\x0e\x32\x10.EPlaytestStatus:\x13k_ETesterStatusNoneBC\x82\xb5\x18?User interest or membership in the playtest for this app if any\x1a\xac\x01\n\x07InQueue\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\x0f\n\x07skipped\x18\x02 \x01(\x08\x12\x17\n\x0fitems_remaining\x18\x03 \x01(\x05\x12\x12\n\nnext_appid\x18\x04 \x01(\r\x12\x1b\n\x13\x65xperimental_cohort\x18\x05 \x01(\r\"$\n\"CStore_GetStorePreferences_Request\"\x99\x04\n\x16\x43Store_UserPreferences\x12\x18\n\x10primary_language\x18\x01 \x01(\x05\x12\x1b\n\x13secondary_languages\x18\x02 \x01(\r\x12\x18\n\x10platform_windows\x18\x03 \x01(\x08\x12\x14\n\x0cplatform_mac\x18\x04 \x01(\x08\x12\x16\n\x0eplatform_linux\x18\x05 \x01(\x08\x12#\n\x1bhide_adult_content_violence\x18\x06 \x01(\x08\x12\x1e\n\x16hide_adult_content_sex\x18\x07 \x01(\x08\x12\x19\n\x11timestamp_updated\x18\x08 \x01(\r\x12\x1c\n\x14hide_store_broadcast\x18\t \x01(\x08\x12`\n\x17review_score_preference\x18\n \x01(\x0e\x32\x1b.EUserReviewScorePreference:\"k_EUserReviewScorePreference_Unset\x12\x38\n0timestamp_content_descriptor_preferences_updated\x18\x0b \x01(\x05\x12\x66\n\x15provide_deck_feedback\x18\x0c \x01(\x0e\x32\x1f.EProvideDeckFeedbackPreference:&k_EProvideDeckFeedbackPreference_Unset\"\x91\x01\n\x19\x43Store_UserTagPreferences\x12\x37\n\x0ftags_to_exclude\x18\x01 \x03(\x0b\x32\x1e.CStore_UserTagPreferences.Tag\x1a;\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0ftimestamp_added\x18\x03 \x01(\r\"\xd9\x01\n\'CStore_UserContentDescriptorPreferences\x12\x62\n\x1e\x63ontent_descriptors_to_exclude\x18\x01 \x03(\x0b\x32:.CStore_UserContentDescriptorPreferences.ContentDescriptor\x1aJ\n\x11\x43ontentDescriptor\x12\x1c\n\x14\x63ontent_descriptorid\x18\x01 \x01(\r\x12\x17\n\x0ftimestamp_added\x18\x02 \x01(\r\"\xda\x01\n#CStore_GetStorePreferences_Response\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12P\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32(.CStore_UserContentDescriptorPreferences\"W\n*CStore_GetTrendingAppsAmongFriends_Request\x12\x10\n\x08num_apps\x18\x01 \x01(\r\x12\x17\n\x0fnum_top_friends\x18\x02 \x01(\r\"\xd9\x01\n+CStore_GetTrendingAppsAmongFriends_Response\x12S\n\rtrending_apps\x18\x01 \x03(\x0b\x32<.CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData\x1aU\n\x0fTrendingAppData\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1c\n\x14steamids_top_friends\x18\x02 \x03(\x04\x12\x15\n\rtotal_friends\x18\x03 \x01(\r\"\x99\x01\n+CSteamDeckCompatibility_SetFeedback_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12[\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0e\x32 .ESteamDeckCompatibilityFeedback:\'k_ESteamDeckCompatibilityFeedback_Unset\".\n,CSteamDeckCompatibility_SetFeedback_Response\"=\n,CSteamDeckCompatibility_ShouldPrompt_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xc0\x01\n-CSteamDeckCompatibility_ShouldPrompt_Response\x12\x0e\n\x06prompt\x18\x01 \x01(\x08\x12\x19\n\x11\x66\x65\x65\x64\x62\x61\x63k_eligible\x18\x02 \x01(\x08\x12\x64\n\x11\x65xisting_feedback\x18\x03 \x01(\x0e\x32 .ESteamDeckCompatibilityFeedback:\'k_ESteamDeckCompatibilityFeedback_Unset\"\xe2\x01\n+CStore_StorePreferencesChanged_Notification\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12P\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32(.CStore_UserContentDescriptorPreferences*\xab\x05\n\x18\x45StoreDiscoveryQueueType\x12!\n\x1dk_EStoreDiscoveryQueueTypeNew\x10\x00\x12(\n$k_EStoreDiscoveryQueueTypeComingSoon\x10\x01\x12)\n%k_EStoreDiscoveryQueueTypeRecommended\x10\x02\x12-\n)k_EStoreDiscoveryQueueTypeEveryNewRelease\x10\x03\x12+\n\'k_EStoreDiscoveryQueueTypeMLRecommender\x10\x05\x12,\n(k_EStoreDiscoveryQueueTypeWishlistOnSale\x10\x06\x12!\n\x1dk_EStoreDiscoveryQueueTypeDLC\x10\x07\x12\'\n#k_EStoreDiscoveryQueueTypeDLCOnSale\x10\x08\x12\x33\n/k_EStoreDiscoveryQueueTypeRecommendedComingSoon\x10\t\x12-\n)k_EStoreDiscoveryQueueTypeRecommendedFree\x10\n\x12/\n+k_EStoreDiscoveryQueueTypeRecommendedOnSale\x10\x0b\x12.\n*k_EStoreDiscoveryQueueTypeRecommendedDemos\x10\x0c\x12,\n(k_EStoreDiscoveryQueueTypeDLCNewReleases\x10\r\x12+\n\'k_EStoreDiscoveryQueueTypeDLCTopSellers\x10\x0e\x12!\n\x1dk_EStoreDiscoveryQueueTypeMAX\x10\x0f*~\n\x0f\x45PlaytestStatus\x12\x17\n\x13k_ETesterStatusNone\x10\x00\x12\x1a\n\x16k_ETesterStatusPending\x10\x01\x12\x1a\n\x16k_ETesterStatusInvited\x10\x02\x12\x1a\n\x16k_ETesterStatusGranted\x10\x03*\xa0\x01\n\x1a\x45UserReviewScorePreference\x12&\n\"k_EUserReviewScorePreference_Unset\x10\x00\x12+\n\'k_EUserReviewScorePreference_IncludeAll\x10\x01\x12-\n)k_EUserReviewScorePreference_ExcludeBombs\x10\x02\x32\xc4\x0f\n\x05Store\x12\x91\x01\n\rRegisterCDKey\x12\x1d.CStore_RegisterCDKey_Request\x1a\x1e.CStore_RegisterCDKey_Response\"A\x82\xb5\x18=Registers a CD key with Steam on the logged in user\'s account\x12\x92\x01\n\x12GetMostPopularTags\x12\".CStore_GetMostPopularTags_Request\x1a#.CStore_GetMostPopularTags_Response\"3\x82\xb5\x18/Get all whitelisted tags, with localized names.\x12\x98\x01\n\x17GetLocalizedNameForTags\x12\'.CStore_GetLocalizedNameForTags_Request\x1a(.CStore_GetLocalizedNameForTags_Response\"*\x82\xb5\x18&Gets tag names in a different language\x12\x99\x01\n\x11GetDiscoveryQueue\x12!.CStore_GetDiscoveryQueue_Request\x1a\".CStore_GetDiscoveryQueue_Response\"=\x82\xb5\x18\x39Get a list of games for the user to explore on the store.\x12\xbd\x01\n\x19GetDiscoveryQueueSettings\x12).CStore_GetDiscoveryQueueSettings_Request\x1a*.CStore_GetDiscoveryQueueSettings_Response\"I\x82\xb5\x18\x45Get the settings that were used to generate a user\'s discovery queue.\x12\x90\x01\n\x16SkipDiscoveryQueueItem\x12&.CStore_SkipDiscoveryQueueItem_Request\x1a\'.CStore_SkipDiscoveryQueueItem_Response\"%\x82\xb5\x18!Skip an item in the user\'s queue.\x12\xdd\x01\n\x18GetUserGameInterestState\x12(.CStore_GetUserGameInterestState_Request\x1a).CStore_GetUserGameInterestState_Response\"l\x82\xb5\x18hGet information about a user\'s relationship to a game - ownership, wishlist, discovery queue state, etc.\x12\xaf\x01\n\x13GetStorePreferences\x12#.CStore_GetStorePreferences_Request\x1a$.CStore_GetStorePreferences_Response\"M\x82\xb5\x18IReturns the desired ratings board and maximum rating to show on the store\x12\x9d\x01\n\x1bGetTrendingAppsAmongFriends\x12+.CStore_GetTrendingAppsAmongFriends_Request\x1a,.CStore_GetTrendingAppsAmongFriends_Response\"#\x82\xb5\x18\x1fGet trending apps among friends\x12\xd5\x01\n\x18SetCompatibilityFeedback\x12,.CSteamDeckCompatibility_SetFeedback_Request\x1a-.CSteamDeckCompatibility_SetFeedback_Response\"\\\x82\xb5\x18XUpserts user feedback regarding the published Steam Deck Compatibility rating for a game\x12\xd8\x01\n$ShouldPromptForCompatibilityFeedback\x12-.CSteamDeckCompatibility_ShouldPrompt_Request\x1a..CSteamDeckCompatibility_ShouldPrompt_Response\"Q\x82\xb5\x18MReturns whether we should ask the user if the compatibility rating is correct\x1a#\x82\xb5\x18\x1f\x41 service to access store data.2\xee\x01\n\x0bStoreClient\x12\xb1\x01\n\x1dNotifyStorePreferencesChanged\x12,.CStore_StorePreferencesChanged_Notification\x1a\x0b.NoResponse\"U\x82\xb5\x18QNotification from server to client that the user\'s store preferences have changed\x1a+\x82\xb5\x18#Steam store to client notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,enums__pb2.DESCRIPTOR,])

_ESTOREDISCOVERYQUEUETYPE = _descriptor.EnumDescriptor(
  name='EStoreDiscoveryQueueType',
  full_name='EStoreDiscoveryQueueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeNew', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeComingSoon', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeRecommended', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeEveryNewRelease', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeMLRecommender', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeWishlistOnSale', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeDLC', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeDLCOnSale', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeRecommendedComingSoon', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeRecommendedFree', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeRecommendedOnSale', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeRecommendedDemos', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeDLCNewReleases', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeDLCTopSellers', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreDiscoveryQueueTypeMAX', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6513,
  serialized_end=7196,
)
_sym_db.RegisterEnumDescriptor(_ESTOREDISCOVERYQUEUETYPE)

EStoreDiscoveryQueueType = enum_type_wrapper.EnumTypeWrapper(_ESTOREDISCOVERYQUEUETYPE)
_EPLAYTESTSTATUS = _descriptor.EnumDescriptor(
  name='EPlaytestStatus',
  full_name='EPlaytestStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETesterStatusNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETesterStatusPending', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETesterStatusInvited', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETesterStatusGranted', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7198,
  serialized_end=7324,
)
_sym_db.RegisterEnumDescriptor(_EPLAYTESTSTATUS)

EPlaytestStatus = enum_type_wrapper.EnumTypeWrapper(_EPLAYTESTSTATUS)
_EUSERREVIEWSCOREPREFERENCE = _descriptor.EnumDescriptor(
  name='EUserReviewScorePreference',
  full_name='EUserReviewScorePreference',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_Unset', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_IncludeAll', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_ExcludeBombs', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7327,
  serialized_end=7487,
)
_sym_db.RegisterEnumDescriptor(_EUSERREVIEWSCOREPREFERENCE)

EUserReviewScorePreference = enum_type_wrapper.EnumTypeWrapper(_EUSERREVIEWSCOREPREFERENCE)
k_EStoreDiscoveryQueueTypeNew = 0
k_EStoreDiscoveryQueueTypeComingSoon = 1
k_EStoreDiscoveryQueueTypeRecommended = 2
k_EStoreDiscoveryQueueTypeEveryNewRelease = 3
k_EStoreDiscoveryQueueTypeMLRecommender = 5
k_EStoreDiscoveryQueueTypeWishlistOnSale = 6
k_EStoreDiscoveryQueueTypeDLC = 7
k_EStoreDiscoveryQueueTypeDLCOnSale = 8
k_EStoreDiscoveryQueueTypeRecommendedComingSoon = 9
k_EStoreDiscoveryQueueTypeRecommendedFree = 10
k_EStoreDiscoveryQueueTypeRecommendedOnSale = 11
k_EStoreDiscoveryQueueTypeRecommendedDemos = 12
k_EStoreDiscoveryQueueTypeDLCNewReleases = 13
k_EStoreDiscoveryQueueTypeDLCTopSellers = 14
k_EStoreDiscoveryQueueTypeMAX = 15
k_ETesterStatusNone = 0
k_ETesterStatusPending = 1
k_ETesterStatusInvited = 2
k_ETesterStatusGranted = 3
k_EUserReviewScorePreference_Unset = 0
k_EUserReviewScorePreference_IncludeAll = 1
k_EUserReviewScorePreference_ExcludeBombs = 2



_CSTORE_REGISTERCDKEY_REQUEST = _descriptor.Descriptor(
  name='CStore_RegisterCDKey_Request',
  full_name='CStore_RegisterCDKey_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='CStore_RegisterCDKey_Request.activation_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306Key string to register on the logged in user\'s account', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_platform', full_name='CStore_RegisterCDKey_Request.purchase_platform', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)EPurchasePlatform for platform of request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_request_from_client', full_name='CStore_RegisterCDKey_Request.is_request_from_client', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>True if the request was initiated from inside the Steam client', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=392,
)


_CSTORE_PURCHASERECEIPTINFO_LINEITEM = _descriptor.Descriptor(
  name='LineItem',
  full_name='CStore_PurchaseReceiptInfo.LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CStore_PurchaseReceiptInfo.LineItem.packageid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CStore_PurchaseReceiptInfo.LineItem.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_item_description', full_name='CStore_PurchaseReceiptInfo.LineItem.line_item_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=934,
)

_CSTORE_PURCHASERECEIPTINFO = _descriptor.Descriptor(
  name='CStore_PurchaseReceiptInfo',
  full_name='CStore_PurchaseReceiptInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionid', full_name='CStore_PurchaseReceiptInfo.transactionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CStore_PurchaseReceiptInfo.packageid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_status', full_name='CStore_PurchaseReceiptInfo.purchase_status', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_detail', full_name='CStore_PurchaseReceiptInfo.result_detail', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_time', full_name='CStore_PurchaseReceiptInfo.transaction_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_method', full_name='CStore_PurchaseReceiptInfo.payment_method', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_price', full_name='CStore_PurchaseReceiptInfo.base_price', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_discount', full_name='CStore_PurchaseReceiptInfo.total_discount', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tax', full_name='CStore_PurchaseReceiptInfo.tax', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shipping', full_name='CStore_PurchaseReceiptInfo.shipping', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='CStore_PurchaseReceiptInfo.currency_code', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CStore_PurchaseReceiptInfo.country_code', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_headline', full_name='CStore_PurchaseReceiptInfo.error_headline', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_string', full_name='CStore_PurchaseReceiptInfo.error_string', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_link_text', full_name='CStore_PurchaseReceiptInfo.error_link_text', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_link_url', full_name='CStore_PurchaseReceiptInfo.error_link_url', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_appid', full_name='CStore_PurchaseReceiptInfo.error_appid', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_items', full_name='CStore_PurchaseReceiptInfo.line_items', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_PURCHASERECEIPTINFO_LINEITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=934,
)


_CSTORE_REGISTERCDKEY_RESPONSE = _descriptor.Descriptor(
  name='CStore_RegisterCDKey_Response',
  full_name='CStore_RegisterCDKey_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purchase_result_details', full_name='CStore_RegisterCDKey_Response.purchase_result_details', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*EPurchaseResultDetails from key activation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_receipt_info', full_name='CStore_RegisterCDKey_Response.purchase_receipt_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025Purchase receipt info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1136,
)


_CSTORE_GETMOSTPOPULARTAGS_REQUEST = _descriptor.Descriptor(
  name='CStore_GetMostPopularTags_Request',
  full_name='CStore_GetMostPopularTags_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CStore_GetMostPopularTags_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1191,
)


_CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='CStore_GetMostPopularTags_Response.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='CStore_GetMostPopularTags_Response.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStore_GetMostPopularTags_Response.Tag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1286,
  serialized_end=1320,
)

_CSTORE_GETMOSTPOPULARTAGS_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetMostPopularTags_Response',
  full_name='CStore_GetMostPopularTags_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='CStore_GetMostPopularTags_Response.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1193,
  serialized_end=1320,
)


_CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST = _descriptor.Descriptor(
  name='CStore_GetLocalizedNameForTags_Request',
  full_name='CStore_GetLocalizedNameForTags_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CStore_GetLocalizedNameForTags_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagids', full_name='CStore_GetLocalizedNameForTags_Request.tagids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1396,
)


_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='CStore_GetLocalizedNameForTags_Response.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='CStore_GetLocalizedNameForTags_Response.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='english_name', full_name='CStore_GetLocalizedNameForTags_Response.Tag.english_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStore_GetLocalizedNameForTags_Response.Tag.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalized_name', full_name='CStore_GetLocalizedNameForTags_Response.Tag.normalized_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Zenglish_name, lowercase, with homoglyphs replaced and spaces and some punctuation removed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1680,
)

_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetLocalizedNameForTags_Response',
  full_name='CStore_GetLocalizedNameForTags_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='CStore_GetLocalizedNameForTags_Response.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1399,
  serialized_end=1680,
)


_CSTOREDISCOVERYQUEUESETTINGS = _descriptor.Descriptor(
  name='CStoreDiscoveryQueueSettings',
  full_name='CStoreDiscoveryQueueSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='os_win', full_name='CStoreDiscoveryQueueSettings.os_win', index=0,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os_mac', full_name='CStoreDiscoveryQueueSettings.os_mac', index=1,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os_linux', full_name='CStoreDiscoveryQueueSettings.os_linux', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_controller_support', full_name='CStoreDiscoveryQueueSettings.full_controller_support', index=3,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='native_steam_controller', full_name='CStoreDiscoveryQueueSettings.native_steam_controller', index=4,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_coming_soon', full_name='CStoreDiscoveryQueueSettings.include_coming_soon', index=5,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_tagids', full_name='CStoreDiscoveryQueueSettings.excluded_tagids', index=6,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Don\'t return any games with these tags.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_early_access', full_name='CStoreDiscoveryQueueSettings.exclude_early_access', index=7,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_videos', full_name='CStoreDiscoveryQueueSettings.exclude_videos', index=8,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_software', full_name='CStoreDiscoveryQueueSettings.exclude_software', index=9,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_dlc', full_name='CStoreDiscoveryQueueSettings.exclude_dlc', index=10,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_soundtracks', full_name='CStoreDiscoveryQueueSettings.exclude_soundtracks', index=11,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='featured_tagids', full_name='CStoreDiscoveryQueueSettings.featured_tagids', index=12,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030LMust be marked with one of these featured tagids (for sale pages and events)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=2165,
)


_CSTORE_GETDISCOVERYQUEUE_REQUEST = _descriptor.Descriptor(
  name='CStore_GetDiscoveryQueue_Request',
  full_name='CStore_GetDiscoveryQueue_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_type', full_name='CStore_GetDiscoveryQueue_Request.queue_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CStore_GetDiscoveryQueue_Request.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rebuild_queue', full_name='CStore_GetDiscoveryQueue_Request.rebuild_queue', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings_changed', full_name='CStore_GetDiscoveryQueue_Request.settings_changed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CStore_GetDiscoveryQueue_Request.settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rebuild_queue_if_stale', full_name='CStore_GetDiscoveryQueue_Request.rebuild_queue_if_stale', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_user_preferences', full_name='CStore_GetDiscoveryQueue_Request.ignore_user_preferences', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_experimental_results', full_name='CStore_GetDiscoveryQueue_Request.no_experimental_results', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimental_cohort', full_name='CStore_GetDiscoveryQueue_Request.experimental_cohort', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_get_solr_query', full_name='CStore_GetDiscoveryQueue_Request.debug_get_solr_query', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2168,
  serialized_end=2557,
)


_CSTORE_GETDISCOVERYQUEUE_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetDiscoveryQueue_Response',
  full_name='CStore_GetDiscoveryQueue_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CStore_GetDiscoveryQueue_Response.appids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CStore_GetDiscoveryQueue_Response.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CStore_GetDiscoveryQueue_Response.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='CStore_GetDiscoveryQueue_Response.skipped', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exhausted', full_name='CStore_GetDiscoveryQueue_Response.exhausted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimental_cohort', full_name='CStore_GetDiscoveryQueue_Response.experimental_cohort', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_solr_query', full_name='CStore_GetDiscoveryQueue_Response.debug_solr_query', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2560,
  serialized_end=2773,
)


_CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST = _descriptor.Descriptor(
  name='CStore_GetDiscoveryQueueSettings_Request',
  full_name='CStore_GetDiscoveryQueueSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_type', full_name='CStore_GetDiscoveryQueueSettings_Request.queue_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2775,
  serialized_end=2895,
)


_CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetDiscoveryQueueSettings_Response',
  full_name='CStore_GetDiscoveryQueueSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CStore_GetDiscoveryQueueSettings_Response.country_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CStore_GetDiscoveryQueueSettings_Response.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2897,
  serialized_end=3011,
)


_CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST = _descriptor.Descriptor(
  name='CStore_SkipDiscoveryQueueItem_Request',
  full_name='CStore_SkipDiscoveryQueueItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_type', full_name='CStore_SkipDiscoveryQueueItem_Request.queue_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CStore_SkipDiscoveryQueueItem_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3014,
  serialized_end=3146,
)


_CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE = _descriptor.Descriptor(
  name='CStore_SkipDiscoveryQueueItem_Response',
  full_name='CStore_SkipDiscoveryQueueItem_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3148,
  serialized_end=3188,
)


_CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST = _descriptor.Descriptor(
  name='CStore_GetUserGameInterestState_Request',
  full_name='CStore_GetUserGameInterestState_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CStore_GetUserGameInterestState_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_appid', full_name='CStore_GetUserGameInterestState_Request.store_appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta_appid', full_name='CStore_GetUserGameInterestState_Request.beta_appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3190,
  serialized_end=3287,
)


_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE = _descriptor.Descriptor(
  name='InQueue',
  full_name='CStore_GetUserGameInterestState_Response.InQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CStore_GetUserGameInterestState_Response.InQueue.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='CStore_GetUserGameInterestState_Response.InQueue.skipped', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items_remaining', full_name='CStore_GetUserGameInterestState_Response.InQueue.items_remaining', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_appid', full_name='CStore_GetUserGameInterestState_Response.InQueue.next_appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimental_cohort', full_name='CStore_GetUserGameInterestState_Response.InQueue.experimental_cohort', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4171,
  serialized_end=4343,
)

_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetUserGameInterestState_Response',
  full_name='CStore_GetUserGameInterestState_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owned', full_name='CStore_GetUserGameInterestState_Response.owned', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wishlist', full_name='CStore_GetUserGameInterestState_Response.wishlist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignored', full_name='CStore_GetUserGameInterestState_Response.ignored', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='following', full_name='CStore_GetUserGameInterestState_Response.following', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_queues', full_name='CStore_GetUserGameInterestState_Response.in_queues', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queues_with_skip', full_name='CStore_GetUserGameInterestState_Response.queues_with_skip', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030;Discovery queue types where the user has skipped this game.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_items_remaining', full_name='CStore_GetUserGameInterestState_Response.queue_items_remaining', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Q# of items remaining in the discovery queue - matches the same order as in_queues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_items_next_appid', full_name='CStore_GetUserGameInterestState_Response.queue_items_next_appid', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Athe next appid in the queue - matches the same order as in_queues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporarily_owned', full_name='CStore_GetUserGameInterestState_Response.temporarily_owned', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?The user owns the game temporarily, eg a rental or free weekend', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queues', full_name='CStore_GetUserGameInterestState_Response.queues', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignored_reason', full_name='CStore_GetUserGameInterestState_Response.ignored_reason', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<The ERecommendationIgnoreReason why the user ignored the app', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta_status', full_name='CStore_GetUserGameInterestState_Response.beta_status', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?User interest or membership in the playtest for this app if any', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3290,
  serialized_end=4343,
)


_CSTORE_GETSTOREPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CStore_GetStorePreferences_Request',
  full_name='CStore_GetStorePreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4345,
  serialized_end=4381,
)


_CSTORE_USERPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserPreferences',
  full_name='CStore_UserPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_language', full_name='CStore_UserPreferences.primary_language', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_languages', full_name='CStore_UserPreferences.secondary_languages', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_windows', full_name='CStore_UserPreferences.platform_windows', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_mac', full_name='CStore_UserPreferences.platform_mac', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_linux', full_name='CStore_UserPreferences.platform_linux', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_adult_content_violence', full_name='CStore_UserPreferences.hide_adult_content_violence', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_adult_content_sex', full_name='CStore_UserPreferences.hide_adult_content_sex', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_updated', full_name='CStore_UserPreferences.timestamp_updated', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_store_broadcast', full_name='CStore_UserPreferences.hide_store_broadcast', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='review_score_preference', full_name='CStore_UserPreferences.review_score_preference', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_content_descriptor_preferences_updated', full_name='CStore_UserPreferences.timestamp_content_descriptor_preferences_updated', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provide_deck_feedback', full_name='CStore_UserPreferences.provide_deck_feedback', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4384,
  serialized_end=4921,
)


_CSTORE_USERTAGPREFERENCES_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='CStore_UserTagPreferences.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='CStore_UserTagPreferences.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStore_UserTagPreferences.Tag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_added', full_name='CStore_UserTagPreferences.Tag.timestamp_added', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5010,
  serialized_end=5069,
)

_CSTORE_USERTAGPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserTagPreferences',
  full_name='CStore_UserTagPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags_to_exclude', full_name='CStore_UserTagPreferences.tags_to_exclude', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_USERTAGPREFERENCES_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4924,
  serialized_end=5069,
)


_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR = _descriptor.Descriptor(
  name='ContentDescriptor',
  full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_descriptorid', full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor.content_descriptorid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_added', full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor.timestamp_added', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5215,
  serialized_end=5289,
)

_CSTORE_USERCONTENTDESCRIPTORPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserContentDescriptorPreferences',
  full_name='CStore_UserContentDescriptorPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_descriptors_to_exclude', full_name='CStore_UserContentDescriptorPreferences.content_descriptors_to_exclude', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5072,
  serialized_end=5289,
)


_CSTORE_GETSTOREPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetStorePreferences_Response',
  full_name='CStore_GetStorePreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CStore_GetStorePreferences_Response.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_preferences', full_name='CStore_GetStorePreferences_Response.tag_preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_descriptor_preferences', full_name='CStore_GetStorePreferences_Response.content_descriptor_preferences', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5292,
  serialized_end=5510,
)


_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST = _descriptor.Descriptor(
  name='CStore_GetTrendingAppsAmongFriends_Request',
  full_name='CStore_GetTrendingAppsAmongFriends_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_apps', full_name='CStore_GetTrendingAppsAmongFriends_Request.num_apps', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_top_friends', full_name='CStore_GetTrendingAppsAmongFriends_Request.num_top_friends', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5512,
  serialized_end=5599,
)


_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA = _descriptor.Descriptor(
  name='TrendingAppData',
  full_name='CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamids_top_friends', full_name='CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData.steamids_top_friends', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_friends', full_name='CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData.total_friends', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5734,
  serialized_end=5819,
)

_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetTrendingAppsAmongFriends_Response',
  full_name='CStore_GetTrendingAppsAmongFriends_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trending_apps', full_name='CStore_GetTrendingAppsAmongFriends_Response.trending_apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5602,
  serialized_end=5819,
)


_CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST = _descriptor.Descriptor(
  name='CSteamDeckCompatibility_SetFeedback_Request',
  full_name='CSteamDeckCompatibility_SetFeedback_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamDeckCompatibility_SetFeedback_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='CSteamDeckCompatibility_SetFeedback_Request.feedback', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5822,
  serialized_end=5975,
)


_CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE = _descriptor.Descriptor(
  name='CSteamDeckCompatibility_SetFeedback_Response',
  full_name='CSteamDeckCompatibility_SetFeedback_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5977,
  serialized_end=6023,
)


_CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST = _descriptor.Descriptor(
  name='CSteamDeckCompatibility_ShouldPrompt_Request',
  full_name='CSteamDeckCompatibility_ShouldPrompt_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamDeckCompatibility_ShouldPrompt_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6025,
  serialized_end=6086,
)


_CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE = _descriptor.Descriptor(
  name='CSteamDeckCompatibility_ShouldPrompt_Response',
  full_name='CSteamDeckCompatibility_ShouldPrompt_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prompt', full_name='CSteamDeckCompatibility_ShouldPrompt_Response.prompt', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_eligible', full_name='CSteamDeckCompatibility_ShouldPrompt_Response.feedback_eligible', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='existing_feedback', full_name='CSteamDeckCompatibility_ShouldPrompt_Response.existing_feedback', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6089,
  serialized_end=6281,
)


_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CStore_StorePreferencesChanged_Notification',
  full_name='CStore_StorePreferencesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CStore_StorePreferencesChanged_Notification.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_preferences', full_name='CStore_StorePreferencesChanged_Notification.tag_preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_descriptor_preferences', full_name='CStore_StorePreferencesChanged_Notification.content_descriptor_preferences', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6284,
  serialized_end=6510,
)

_CSTORE_PURCHASERECEIPTINFO_LINEITEM.containing_type = _CSTORE_PURCHASERECEIPTINFO
_CSTORE_PURCHASERECEIPTINFO.fields_by_name['line_items'].message_type = _CSTORE_PURCHASERECEIPTINFO_LINEITEM
_CSTORE_REGISTERCDKEY_RESPONSE.fields_by_name['purchase_receipt_info'].message_type = _CSTORE_PURCHASERECEIPTINFO
_CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG.containing_type = _CSTORE_GETMOSTPOPULARTAGS_RESPONSE
_CSTORE_GETMOSTPOPULARTAGS_RESPONSE.fields_by_name['tags'].message_type = _CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG
_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG.containing_type = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE
_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE.fields_by_name['tags'].message_type = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG
_CSTORE_GETDISCOVERYQUEUE_REQUEST.fields_by_name['queue_type'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETDISCOVERYQUEUE_REQUEST.fields_by_name['settings'].message_type = _CSTOREDISCOVERYQUEUESETTINGS
_CSTORE_GETDISCOVERYQUEUE_RESPONSE.fields_by_name['settings'].message_type = _CSTOREDISCOVERYQUEUESETTINGS
_CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST.fields_by_name['queue_type'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE.fields_by_name['settings'].message_type = _CSTOREDISCOVERYQUEUESETTINGS
_CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST.fields_by_name['queue_type'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE.fields_by_name['type'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE.containing_type = _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['in_queues'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['queues_with_skip'].enum_type = _ESTOREDISCOVERYQUEUETYPE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['queues'].message_type = _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['beta_status'].enum_type = _EPLAYTESTSTATUS
_CSTORE_USERPREFERENCES.fields_by_name['review_score_preference'].enum_type = _EUSERREVIEWSCOREPREFERENCE
_CSTORE_USERPREFERENCES.fields_by_name['provide_deck_feedback'].enum_type = enums__pb2._EPROVIDEDECKFEEDBACKPREFERENCE
_CSTORE_USERTAGPREFERENCES_TAG.containing_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_USERTAGPREFERENCES.fields_by_name['tags_to_exclude'].message_type = _CSTORE_USERTAGPREFERENCES_TAG
_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR.containing_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
_CSTORE_USERCONTENTDESCRIPTORPREFERENCES.fields_by_name['content_descriptors_to_exclude'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['preferences'].message_type = _CSTORE_USERPREFERENCES
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['tag_preferences'].message_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['content_descriptor_preferences'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA.containing_type = _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE
_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE.fields_by_name['trending_apps'].message_type = _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA
_CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST.fields_by_name['feedback'].enum_type = enums__pb2._ESTEAMDECKCOMPATIBILITYFEEDBACK
_CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE.fields_by_name['existing_feedback'].enum_type = enums__pb2._ESTEAMDECKCOMPATIBILITYFEEDBACK
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['preferences'].message_type = _CSTORE_USERPREFERENCES
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['tag_preferences'].message_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['content_descriptor_preferences'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_RegisterCDKey_Request'] = _CSTORE_REGISTERCDKEY_REQUEST
DESCRIPTOR.message_types_by_name['CStore_PurchaseReceiptInfo'] = _CSTORE_PURCHASERECEIPTINFO
DESCRIPTOR.message_types_by_name['CStore_RegisterCDKey_Response'] = _CSTORE_REGISTERCDKEY_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetMostPopularTags_Request'] = _CSTORE_GETMOSTPOPULARTAGS_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetMostPopularTags_Response'] = _CSTORE_GETMOSTPOPULARTAGS_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetLocalizedNameForTags_Request'] = _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetLocalizedNameForTags_Response'] = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE
DESCRIPTOR.message_types_by_name['CStoreDiscoveryQueueSettings'] = _CSTOREDISCOVERYQUEUESETTINGS
DESCRIPTOR.message_types_by_name['CStore_GetDiscoveryQueue_Request'] = _CSTORE_GETDISCOVERYQUEUE_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetDiscoveryQueue_Response'] = _CSTORE_GETDISCOVERYQUEUE_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetDiscoveryQueueSettings_Request'] = _CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetDiscoveryQueueSettings_Response'] = _CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_SkipDiscoveryQueueItem_Request'] = _CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST
DESCRIPTOR.message_types_by_name['CStore_SkipDiscoveryQueueItem_Response'] = _CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetUserGameInterestState_Request'] = _CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetUserGameInterestState_Response'] = _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetStorePreferences_Request'] = _CSTORE_GETSTOREPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CStore_UserPreferences'] = _CSTORE_USERPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_UserTagPreferences'] = _CSTORE_USERTAGPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_UserContentDescriptorPreferences'] = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_GetStorePreferences_Response'] = _CSTORE_GETSTOREPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetTrendingAppsAmongFriends_Request'] = _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetTrendingAppsAmongFriends_Response'] = _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamDeckCompatibility_SetFeedback_Request'] = _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST
DESCRIPTOR.message_types_by_name['CSteamDeckCompatibility_SetFeedback_Response'] = _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamDeckCompatibility_ShouldPrompt_Request'] = _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST
DESCRIPTOR.message_types_by_name['CSteamDeckCompatibility_ShouldPrompt_Response'] = _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_StorePreferencesChanged_Notification'] = _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EStoreDiscoveryQueueType'] = _ESTOREDISCOVERYQUEUETYPE
DESCRIPTOR.enum_types_by_name['EPlaytestStatus'] = _EPLAYTESTSTATUS
DESCRIPTOR.enum_types_by_name['EUserReviewScorePreference'] = _EUSERREVIEWSCOREPREFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CStore_RegisterCDKey_Request = _reflection.GeneratedProtocolMessageType('CStore_RegisterCDKey_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_REGISTERCDKEY_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_RegisterCDKey_Request)
  })
_sym_db.RegisterMessage(CStore_RegisterCDKey_Request)

CStore_PurchaseReceiptInfo = _reflection.GeneratedProtocolMessageType('CStore_PurchaseReceiptInfo', (_message.Message,), {

  'LineItem' : _reflection.GeneratedProtocolMessageType('LineItem', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_PURCHASERECEIPTINFO_LINEITEM,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_PurchaseReceiptInfo.LineItem)
    })
  ,
  'DESCRIPTOR' : _CSTORE_PURCHASERECEIPTINFO,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_PurchaseReceiptInfo)
  })
_sym_db.RegisterMessage(CStore_PurchaseReceiptInfo)
_sym_db.RegisterMessage(CStore_PurchaseReceiptInfo.LineItem)

CStore_RegisterCDKey_Response = _reflection.GeneratedProtocolMessageType('CStore_RegisterCDKey_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_REGISTERCDKEY_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_RegisterCDKey_Response)
  })
_sym_db.RegisterMessage(CStore_RegisterCDKey_Response)

CStore_GetMostPopularTags_Request = _reflection.GeneratedProtocolMessageType('CStore_GetMostPopularTags_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETMOSTPOPULARTAGS_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetMostPopularTags_Request)
  })
_sym_db.RegisterMessage(CStore_GetMostPopularTags_Request)

CStore_GetMostPopularTags_Response = _reflection.GeneratedProtocolMessageType('CStore_GetMostPopularTags_Response', (_message.Message,), {

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_GetMostPopularTags_Response.Tag)
    })
  ,
  'DESCRIPTOR' : _CSTORE_GETMOSTPOPULARTAGS_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetMostPopularTags_Response)
  })
_sym_db.RegisterMessage(CStore_GetMostPopularTags_Response)
_sym_db.RegisterMessage(CStore_GetMostPopularTags_Response.Tag)

CStore_GetLocalizedNameForTags_Request = _reflection.GeneratedProtocolMessageType('CStore_GetLocalizedNameForTags_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Request)
  })
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Request)

CStore_GetLocalizedNameForTags_Response = _reflection.GeneratedProtocolMessageType('CStore_GetLocalizedNameForTags_Response', (_message.Message,), {

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Response.Tag)
    })
  ,
  'DESCRIPTOR' : _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Response)
  })
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Response)
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Response.Tag)

CStoreDiscoveryQueueSettings = _reflection.GeneratedProtocolMessageType('CStoreDiscoveryQueueSettings', (_message.Message,), {
  'DESCRIPTOR' : _CSTOREDISCOVERYQUEUESETTINGS,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStoreDiscoveryQueueSettings)
  })
_sym_db.RegisterMessage(CStoreDiscoveryQueueSettings)

CStore_GetDiscoveryQueue_Request = _reflection.GeneratedProtocolMessageType('CStore_GetDiscoveryQueue_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETDISCOVERYQUEUE_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetDiscoveryQueue_Request)
  })
_sym_db.RegisterMessage(CStore_GetDiscoveryQueue_Request)

CStore_GetDiscoveryQueue_Response = _reflection.GeneratedProtocolMessageType('CStore_GetDiscoveryQueue_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETDISCOVERYQUEUE_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetDiscoveryQueue_Response)
  })
_sym_db.RegisterMessage(CStore_GetDiscoveryQueue_Response)

CStore_GetDiscoveryQueueSettings_Request = _reflection.GeneratedProtocolMessageType('CStore_GetDiscoveryQueueSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetDiscoveryQueueSettings_Request)
  })
_sym_db.RegisterMessage(CStore_GetDiscoveryQueueSettings_Request)

CStore_GetDiscoveryQueueSettings_Response = _reflection.GeneratedProtocolMessageType('CStore_GetDiscoveryQueueSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetDiscoveryQueueSettings_Response)
  })
_sym_db.RegisterMessage(CStore_GetDiscoveryQueueSettings_Response)

CStore_SkipDiscoveryQueueItem_Request = _reflection.GeneratedProtocolMessageType('CStore_SkipDiscoveryQueueItem_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_SkipDiscoveryQueueItem_Request)
  })
_sym_db.RegisterMessage(CStore_SkipDiscoveryQueueItem_Request)

CStore_SkipDiscoveryQueueItem_Response = _reflection.GeneratedProtocolMessageType('CStore_SkipDiscoveryQueueItem_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_SkipDiscoveryQueueItem_Response)
  })
_sym_db.RegisterMessage(CStore_SkipDiscoveryQueueItem_Response)

CStore_GetUserGameInterestState_Request = _reflection.GeneratedProtocolMessageType('CStore_GetUserGameInterestState_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetUserGameInterestState_Request)
  })
_sym_db.RegisterMessage(CStore_GetUserGameInterestState_Request)

CStore_GetUserGameInterestState_Response = _reflection.GeneratedProtocolMessageType('CStore_GetUserGameInterestState_Response', (_message.Message,), {

  'InQueue' : _reflection.GeneratedProtocolMessageType('InQueue', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_GetUserGameInterestState_Response.InQueue)
    })
  ,
  'DESCRIPTOR' : _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetUserGameInterestState_Response)
  })
_sym_db.RegisterMessage(CStore_GetUserGameInterestState_Response)
_sym_db.RegisterMessage(CStore_GetUserGameInterestState_Response.InQueue)

CStore_GetStorePreferences_Request = _reflection.GeneratedProtocolMessageType('CStore_GetStorePreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETSTOREPREFERENCES_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetStorePreferences_Request)
  })
_sym_db.RegisterMessage(CStore_GetStorePreferences_Request)

CStore_UserPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserPreferences', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_USERPREFERENCES,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserPreferences)
  })
_sym_db.RegisterMessage(CStore_UserPreferences)

CStore_UserTagPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserTagPreferences', (_message.Message,), {

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_USERTAGPREFERENCES_TAG,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_UserTagPreferences.Tag)
    })
  ,
  'DESCRIPTOR' : _CSTORE_USERTAGPREFERENCES,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserTagPreferences)
  })
_sym_db.RegisterMessage(CStore_UserTagPreferences)
_sym_db.RegisterMessage(CStore_UserTagPreferences.Tag)

CStore_UserContentDescriptorPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserContentDescriptorPreferences', (_message.Message,), {

  'ContentDescriptor' : _reflection.GeneratedProtocolMessageType('ContentDescriptor', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_UserContentDescriptorPreferences.ContentDescriptor)
    })
  ,
  'DESCRIPTOR' : _CSTORE_USERCONTENTDESCRIPTORPREFERENCES,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserContentDescriptorPreferences)
  })
_sym_db.RegisterMessage(CStore_UserContentDescriptorPreferences)
_sym_db.RegisterMessage(CStore_UserContentDescriptorPreferences.ContentDescriptor)

CStore_GetStorePreferences_Response = _reflection.GeneratedProtocolMessageType('CStore_GetStorePreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETSTOREPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetStorePreferences_Response)
  })
_sym_db.RegisterMessage(CStore_GetStorePreferences_Response)

CStore_GetTrendingAppsAmongFriends_Request = _reflection.GeneratedProtocolMessageType('CStore_GetTrendingAppsAmongFriends_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetTrendingAppsAmongFriends_Request)
  })
_sym_db.RegisterMessage(CStore_GetTrendingAppsAmongFriends_Request)

CStore_GetTrendingAppsAmongFriends_Response = _reflection.GeneratedProtocolMessageType('CStore_GetTrendingAppsAmongFriends_Response', (_message.Message,), {

  'TrendingAppData' : _reflection.GeneratedProtocolMessageType('TrendingAppData', (_message.Message,), {
    'DESCRIPTOR' : _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA,
    '__module__' : 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData)
    })
  ,
  'DESCRIPTOR' : _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetTrendingAppsAmongFriends_Response)
  })
_sym_db.RegisterMessage(CStore_GetTrendingAppsAmongFriends_Response)
_sym_db.RegisterMessage(CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData)

CSteamDeckCompatibility_SetFeedback_Request = _reflection.GeneratedProtocolMessageType('CSteamDeckCompatibility_SetFeedback_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CSteamDeckCompatibility_SetFeedback_Request)
  })
_sym_db.RegisterMessage(CSteamDeckCompatibility_SetFeedback_Request)

CSteamDeckCompatibility_SetFeedback_Response = _reflection.GeneratedProtocolMessageType('CSteamDeckCompatibility_SetFeedback_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CSteamDeckCompatibility_SetFeedback_Response)
  })
_sym_db.RegisterMessage(CSteamDeckCompatibility_SetFeedback_Response)

CSteamDeckCompatibility_ShouldPrompt_Request = _reflection.GeneratedProtocolMessageType('CSteamDeckCompatibility_ShouldPrompt_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CSteamDeckCompatibility_ShouldPrompt_Request)
  })
_sym_db.RegisterMessage(CSteamDeckCompatibility_ShouldPrompt_Request)

CSteamDeckCompatibility_ShouldPrompt_Response = _reflection.GeneratedProtocolMessageType('CSteamDeckCompatibility_ShouldPrompt_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CSteamDeckCompatibility_ShouldPrompt_Response)
  })
_sym_db.RegisterMessage(CSteamDeckCompatibility_ShouldPrompt_Response)

CStore_StorePreferencesChanged_Notification = _reflection.GeneratedProtocolMessageType('CStore_StorePreferencesChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_StorePreferencesChanged_Notification)
  })
_sym_db.RegisterMessage(CStore_StorePreferencesChanged_Notification)


DESCRIPTOR._options = None
_CSTORE_REGISTERCDKEY_REQUEST.fields_by_name['activation_code']._options = None
_CSTORE_REGISTERCDKEY_REQUEST.fields_by_name['purchase_platform']._options = None
_CSTORE_REGISTERCDKEY_REQUEST.fields_by_name['is_request_from_client']._options = None
_CSTORE_REGISTERCDKEY_RESPONSE.fields_by_name['purchase_result_details']._options = None
_CSTORE_REGISTERCDKEY_RESPONSE.fields_by_name['purchase_receipt_info']._options = None
_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG.fields_by_name['normalized_name']._options = None
_CSTOREDISCOVERYQUEUESETTINGS.fields_by_name['excluded_tagids']._options = None
_CSTOREDISCOVERYQUEUESETTINGS.fields_by_name['featured_tagids']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['queues_with_skip']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['queue_items_remaining']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['queue_items_next_appid']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['temporarily_owned']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['ignored_reason']._options = None
_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE.fields_by_name['beta_status']._options = None

_STORE = _descriptor.ServiceDescriptor(
  name='Store',
  full_name='Store',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\037A service to access store data.',
  create_key=_descriptor._internal_create_key,
  serialized_start=7490,
  serialized_end=9478,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterCDKey',
    full_name='Store.RegisterCDKey',
    index=0,
    containing_service=None,
    input_type=_CSTORE_REGISTERCDKEY_REQUEST,
    output_type=_CSTORE_REGISTERCDKEY_RESPONSE,
    serialized_options=b'\202\265\030=Registers a CD key with Steam on the logged in user\'s account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMostPopularTags',
    full_name='Store.GetMostPopularTags',
    index=1,
    containing_service=None,
    input_type=_CSTORE_GETMOSTPOPULARTAGS_REQUEST,
    output_type=_CSTORE_GETMOSTPOPULARTAGS_RESPONSE,
    serialized_options=b'\202\265\030/Get all whitelisted tags, with localized names.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLocalizedNameForTags',
    full_name='Store.GetLocalizedNameForTags',
    index=2,
    containing_service=None,
    input_type=_CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST,
    output_type=_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE,
    serialized_options=b'\202\265\030&Gets tag names in a different language',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDiscoveryQueue',
    full_name='Store.GetDiscoveryQueue',
    index=3,
    containing_service=None,
    input_type=_CSTORE_GETDISCOVERYQUEUE_REQUEST,
    output_type=_CSTORE_GETDISCOVERYQUEUE_RESPONSE,
    serialized_options=b'\202\265\0309Get a list of games for the user to explore on the store.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDiscoveryQueueSettings',
    full_name='Store.GetDiscoveryQueueSettings',
    index=4,
    containing_service=None,
    input_type=_CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST,
    output_type=_CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE,
    serialized_options=b'\202\265\030EGet the settings that were used to generate a user\'s discovery queue.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SkipDiscoveryQueueItem',
    full_name='Store.SkipDiscoveryQueueItem',
    index=5,
    containing_service=None,
    input_type=_CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST,
    output_type=_CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE,
    serialized_options=b'\202\265\030!Skip an item in the user\'s queue.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserGameInterestState',
    full_name='Store.GetUserGameInterestState',
    index=6,
    containing_service=None,
    input_type=_CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST,
    output_type=_CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE,
    serialized_options=b'\202\265\030hGet information about a user\'s relationship to a game - ownership, wishlist, discovery queue state, etc.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStorePreferences',
    full_name='Store.GetStorePreferences',
    index=7,
    containing_service=None,
    input_type=_CSTORE_GETSTOREPREFERENCES_REQUEST,
    output_type=_CSTORE_GETSTOREPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030IReturns the desired ratings board and maximum rating to show on the store',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTrendingAppsAmongFriends',
    full_name='Store.GetTrendingAppsAmongFriends',
    index=8,
    containing_service=None,
    input_type=_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST,
    output_type=_CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE,
    serialized_options=b'\202\265\030\037Get trending apps among friends',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCompatibilityFeedback',
    full_name='Store.SetCompatibilityFeedback',
    index=9,
    containing_service=None,
    input_type=_CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST,
    output_type=_CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE,
    serialized_options=b'\202\265\030XUpserts user feedback regarding the published Steam Deck Compatibility rating for a game',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ShouldPromptForCompatibilityFeedback',
    full_name='Store.ShouldPromptForCompatibilityFeedback',
    index=10,
    containing_service=None,
    input_type=_CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST,
    output_type=_CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE,
    serialized_options=b'\202\265\030MReturns whether we should ask the user if the compatibility rating is correct',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORE)

DESCRIPTOR.services_by_name['Store'] = _STORE


_STORECLIENT = _descriptor.ServiceDescriptor(
  name='StoreClient',
  full_name='StoreClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030#Steam store to client notifications\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=9481,
  serialized_end=9719,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyStorePreferencesChanged',
    full_name='StoreClient.NotifyStorePreferencesChanged',
    index=0,
    containing_service=None,
    input_type=_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030QNotification from server to client that the user\'s store preferences have changed',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORECLIENT)

DESCRIPTOR.services_by_name['StoreClient'] = _STORECLIENT

Store = service_reflection.GeneratedServiceType('Store', (_service.Service,), dict(
  DESCRIPTOR = _STORE,
  __module__ = 'steammessages_store_pb2'
  ))

Store_Stub = service_reflection.GeneratedServiceStubType('Store_Stub', (Store,), dict(
  DESCRIPTOR = _STORE,
  __module__ = 'steammessages_store_pb2'
  ))


StoreClient = service_reflection.GeneratedServiceType('StoreClient', (_service.Service,), dict(
  DESCRIPTOR = _STORECLIENT,
  __module__ = 'steammessages_store_pb2'
  ))

StoreClient_Stub = service_reflection.GeneratedServiceStubType('StoreClient_Stub', (StoreClient,), dict(
  DESCRIPTOR = _STORECLIENT,
  __module__ = 'steammessages_store_pb2'
  ))


# @@protoc_insertion_point(module_scope)
